/*
* This is the master of list of functions.
* All functions must be: "void foo();".
* And be defined in "foo.c".
*
* Please keep in alpha-num order.
*
* These functions may be wrappers for more complex functions.
*
*  IF YOU ADD A FUNCTION HERE THEN ADD IT TO FUNC.C
*  AND UPDATE MAX_FUNC IN FUNC.H
*
* Copyright (C) 2003, David Redick
* Released under the GNU General Public License (v2)
*/

#ifndef LWMAPGEN_FUNC_LIST_H
#define LWMAPGEN_FUNC_LIST_H


void big_quad();
void boxes();
void bubbles();
void circles();
void circuit();
void hole();
void lines();
void rand_box();
void rand_func();
void rand_poly();
void rand_poly_cut();
void street();
void worms();


#endif
